=======
OpenGov
=======

.. image:: https://img.shields.io/pypi/v/opengov.svg
        :target: https://pypi.python.org/pypi/opengov

.. image:: https://readthedocs.org/projects/opengov/badge/?version=latest
        :target: https://opengov.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


Regularly-maintained centralized datahub for the Open Government Initiative.

* Free software: MIT license
* Documentation: https://opengov.readthedocs.io.


Features
--------

OpenGov is maintained weekly. It was last updated on 07/29/2020.

OpenGov is a hub for raw and processed data collected from various departments and government agencies participating in the Open Government initiative.

Data scientists, researchers, and developer no longer need to scrape the internet hunting data for your time critical projects.

Download OpenGov, save your time, go change the world!

Author
-------
Brandon Jin

LinkedIn: www.linkedin.com/in/brandon-jin
